class Error(Exception):
    """Base class for exceptions in this module."""
    pass

class InvalidPasswordOrEmail(Error):
    """Raised when the API returns that the users password or email address is incorrect

    Attributes:
        message -- The error message
    """


    def __init__(self, message):
        self.message = message

class UnexpectedResponse(Error):
    """Raised when the API returns an unexpected response
    Attributes:
        message -- The error message
    """

    def __init__(self, message):
        self.message = message


"""Authenticates with Lay-Z-Spa"""
import asyncio
from datetime import datetime
from .api import Api
class Spa:
    """The class to handle authenticating with the API"""
    def __init__(self, api, did):
        """
        constructor
        """
        self.api = Api({"did": did, "api_token":api})                  

    async def is_online(self):
        """
        Indicates if the device is currently online
        """
        result = await self.api.send_command("is_online")
        return result["data"] == "true"        

    async def update_status(self):        
        """
        Indicates if the device is currently online
        """
        result = await self.api.send_command("status")
        
        data = result["data"]                              
        self.updated_at = datetime.fromtimestamp(data["updated_at"])
        attr = data["attr"]
        
        self.wave_appm_min = attr["wave_appm_min"]
        self.heat_timer_min = attr["heat_timer_min"]
        self.earth = attr["earth"]
        self.wave_timer_min = attr["wave_timer_min"]

        self.filter_timer_min = attr["filter_timer_min"]
        self.heat_appm_min = attr["heat_appm_min"]
        self.filter_appm_min = attr["filter_appm_min"]

        self.locked = attr["locked"]

        self.power = attr["power"] == 1
        self.heat_power = attr["heat_power"] == 1
        self.wave_power = attr["wave_power"] == 1
        self.filter_power = attr["filter_power"] == 1

        self.temp_now = attr["temp_now"]
        self.temp_set = attr["temp_set"]
        self.temp_set_unit ="°C" if attr["temp_set_unit"]=="摄氏" else "°F"
        self.heat_temp_reach = attr["heat_temp_reach"] == 1

        self.system_err1 = attr["system_err1"]
        self.system_err2 = attr["system_err2"]
        self.system_err3 = attr["system_err3"]
        self.system_err4 = attr["system_err4"]
        self.system_err5 = attr["system_err5"]
        self.system_err6 = attr["system_err6"]
        self.system_err7 = attr["system_err7"]
        self.system_err8 = attr["system_err8"]
        self.system_err9 = attr["system_err9"]            

    async def set_power(self, power):
        """
        Turn the spa on or off
        """
        if power:
            await self.api.send_command("turn_on")
            power=True
        else:
            await self.api.send_command("turn_off")
            power=False

    async def set_filter_power(self, power):
        """
        Turn the filter on or off
        """
        if power:
            await self.api.send_command("turn_filter_on")
            filter_power=True
        else:
            await self.api.send_command("turn_filter_off")
            filter_power=False

    async def set_heat_power(self, power):
        """
        Turn the heater on or off
        """
        if power:
            await self.api.send_command("turn_heat_on")
            heat_power=True
        else:
            await self.api.send_command("turn_heat_off")
            heat_power=False

    async def set_wave_power(self, power):
        """
        Turn the bubbles on and off
        """
        if power:
            await self.api.send_command("turn_wave_on")
            wave_power=True
        else:
            await self.api.send_command("turn_wave_off")
            wave_power=False

    async def set_target_temperature(self, temperature):
        """
        Set the target temperature for the spa
        """
        await self.api.send_command("temp_set", {"temperature": temperature})
        target=temperature


"""Authenticates with Lay-Z-Spa"""
from .api import Api
from .const import (
    API_URI,
    API_VERSION
)
class Auth:
    """The class to handle authenticating with the API"""

    def __init__(self):
        """
        constructor
        """

    async def get_token(self, email, password):
        """
        Gets an authentication token for the user
        :type email: str
        :type password: str
        """
        api = Api({"email": email, "password":password}, base_url=API_URI + "/v" + API_VERSION )
        return await api.send_command("/auth/login")


import json
import aiohttp
import asyncio
from datetime import datetime
from .const import (
    API_URI,
    API_VERSION
)
from .errors import InvalidPasswordOrEmail, UnexpectedResponse
class Api:
    """The class to handle communicating with the api"""
    def __init__(self, auth, base_url=API_URI + "/v" + API_VERSION + "/gizwits/"):
        """
        constructor
        """
        self.auth = auth
        self.base_url = base_url

    async def send_command(self, command, query_string={}):       
        async with aiohttp.ClientSession() as session:
            async with session.post(self.base_url+command, data=self.auth,params=query_string) as r:         
                       
                if r.status == 200:
                    return await r.json()
                if r.status == 403:
                    raise InvalidPasswordOrEmail((await r.json())["errors"])        
                r.raise_for_status()
                raise UnexpectedResponse(await r.text())                



from distutils.core import setup

def readme():
    with open('README.rst') as desc:
        return desc.read()

setup(
  name = 'layz_spa',
  packages = ['layz_spa'], 
  version = '0.4',
  license='MIT',
  description = 'An API to control wifi based lay-z spas', 
  long_description=readme(),
  long_description_content_type='text/markdown',
  author = 'Ross Dargan',
  author_email = 'layzspa@the-dargans.co.uk', 
  url = 'https://github.com/rossdargan/', 
  download_url = 'https://github.com/rossdargan/layz-spa-api/archive/0.4.tar.gz',  
  keywords = ['Lazy Spa', 'Layz Spa', 'Lay-z spa'],   
  install_requires=[
          'aiohttp'
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',
    'Intended Audience :: Developers',
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',     
    'Programming Language :: Python :: 3.7',
    'Programming Language :: Python :: 3.8',
    'Programming Language :: Python :: 3.9',
  ],
)